# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

# Build and publish

1. Update pyproject.toml
2. Run `bash build.sh`

# Install

pip install bottlenest
or
pip install bottlenest==0.0.4

# Temporary test

Update the version inside the file below, and run it

[temptest.sh](./temptest.sh)

